@@ -153,13 +153,12 @@ class NERDA:
         if device is None:
             self.device = 'cuda' if torch.cuda.is_available() else 'cpu'
             print("Device automatically set to:", self.device)
+        else:
+            self.device = device
+            print("Device set to:", self.device)
         self.tag_scheme = tag_scheme
         self.tag_outside = tag_outside
-        self.transformer = transformer
-        if dataset_training is None:
-            dataset_training = get_conll_data('train')
-        if dataset_validation is None:
-            dataset_validation = get_conll_data('valid')     
+        self.transformer = transformer  
         self.dataset_training = dataset_training
         self.dataset_validation = dataset_validation
         self.hyperparameters = hyperparameters
